// src/DashedRoundButton.js
import React from 'react';
import PropTypes from 'prop-types';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faArrowUp, faArrowDown, faArrowLeft, faArrowRight } from '@fortawesome/free-solid-svg-icons';
import 'bootstrap/dist/css/bootstrap.min.css';

const DashedRoundButton = ({ direction, variant, rotation }) => {
  const iconMap = {
    up: faArrowUp,
    down: faArrowDown,
    left: faArrowLeft,
    right: faArrowRight,
  };

  const icon = iconMap[direction];

  let buttonStyles = {
    borderRadius: '50%',
    border: '2px dashed',
    width: '50px',
    height: '50px',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
  };

  let iconStyles = {
    color: 'white',
    transform: `rotate(${rotation}deg)`,
  };

  switch (variant) {
    case 'primary':
      buttonStyles.backgroundColor = '#007bff';
      break;
    case 'secondary':
      buttonStyles.backgroundColor = '#6c757d';
      break;
    case 'success':
      buttonStyles.backgroundColor = '#28a745';
      break;
    case 'danger':
      buttonStyles.backgroundColor = '#dc3545';
      break;
    case 'warning':
      buttonStyles.backgroundColor = '#ffc107';
      break;
    case 'info':
      buttonStyles.backgroundColor = '#17a2b8';
      break;
    case 'light':
      buttonStyles.backgroundColor = '#f8f9fa';
      break;
    case 'dark':
      buttonStyles.backgroundColor = '#343a40';
      break;
    default:
      buttonStyles.backgroundColor = '#007bff';
  }

  return (
    <button style={buttonStyles}>
      <FontAwesomeIcon icon={icon} style={iconStyles} />
    </button>
  );
};

DashedRoundButton.propTypes = {
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']).isRequired,
  variant: PropTypes.oneOf(['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark']),
  rotation: PropTypes.number, 
};

DashedRoundButton.defaultProps = {
  variant: 'primary',
  rotation: 0,
};

export default DashedRoundButton;
